Sample covariates using bootstrap
sample_covariates_bootstrap.RdSample covariates using bootstrap
Usage
sample_covariates_bootstrap(
data,
n_subjects = nrow(data),
conditional = NULL,
seed = NULL,
na.rm = TRUE,
...
)Arguments
- data
data.frame (n x p) containing the original, observed, time-invariant covariates (ID should not be included) that will be used to inform the imputation.
- n_subjects
number of simulated subjects, default is the number of subjects in the data.
- conditional
list with conditional limits for sampled population. For continuous covariates, specify a numeric vector of length 2 giving the
c(min, max)range, e.g.list("WT" = c(40, 60), "BMI" = c(15, 25)). For categorical covariates (those listed incat_covs), specify a character vector of the allowed category values, e.g.list("SEX" = c("F")).- seed
integer random seed passed to
set.seed()for reproducibility. DefaultNULLdoes not set a seed.- na.rm
logical. If
TRUE(default), rows withNAin any column are dropped before sampling.- ...
additional arguments passed to
mice::mice()function